===========
cinder.conf
===========

The ``cinder.conf`` file is installed in ``/etc/cinder`` by default.
When you manually install the Block Storage service, the options in the
``cinder.conf`` file are set to default values.

.. only:: html

   The sample configuration file can also be viewed in
   `file form <../../../_static/cinder.conf.sample>`_.

   .. literalinclude:: ../../../_static/cinder.conf.sample
      :language: ini

.. only:: latex

   See the on-line version of this documentation for the full example
   config file.
